@@ -15,6 +15,7 @@ from sqlmodel import Field
 from plexus.common.utils.ormutils import (
     db_activate_snapshot_model,
     db_create_record_model,
+    db_create_serial_model,
     db_create_snapshot_model,
     db_delete_serial_model,
     db_expire_snapshot_model,
@@ -26,6 +27,7 @@ from plexus.common.utils.ormutils import (
     db_read_serial_models,
     db_read_snapshot_models_of_record,
     db_update_record_model,
+    db_update_serial_model,
     db_update_snapshot_model,
 )
 from plexus.common.utils.ormutils import (
@@ -86,6 +88,117 @@ class DummySnapshotModel(DummyBaseModel, make_snapshot_model_mixin(), table=True
     )
 
 
+def test_db_serial_model_crud(fixture_postgresql_test_proc, fixture_postgresql_test):
+    scheme = make_scheme(Dialects.postgresql, Drivers.psycopg)
+    host = fixture_postgresql_test.info.host
+    port = fixture_postgresql_test.info.port
+    user = fixture_postgresql_test.info.user
+    database = fixture_postgresql_test.info.dbname
+
+    maker = ConnectionMaker.create(scheme,
+                                   host,
+                                   port,
+                                   user,
+                                   None,
+                                   database,
+                                   session_opts=dict(expire_on_commit=False))
+
+    DummyBaseModel.metadata.create_all(maker.engine)
+
+    rng = randomizer()
+
+    def random_record() -> DummySerialModel:
+        return DummySerialModel(
+            dummy_int=rng.next_int(0, 1000),
+            dummy_str=rng.random_alphanumeric(rng.next_int(10, 20)),
+            dummy_float=rng.next_float(0.0, 100.0),
+            dummy_bool=rng.next_bool(),
+            dummy_array=list(rng.random_ascii(rng.next_int(10, 20)) for _ in range(rng.next_int(10, 20))),
+            dummy_json=rng.random_json_object(5),
+        )
+
+    with maker.make_session() as session:
+        session.execute(sa.sql.text("SET TIMEZONE TO 'UTC'"))
+        session.commit()
+
+        create_records = [random_record() for _ in range(0, 100)]
+        update_records = [random_record() for _ in range(0, 100)]
+
+        for i in range(0, 100):
+            with pytest.raises(sa_exc.NoResultFound):
+                db_read_serial_model(session, DummySerialModel, i + 1)
+
+        for i in range(0, 100):
+            result = db_create_serial_model(session, DummySerialModel, create_records[i])
+
+            assert result.sid == i + 1
+            assert result.dummy_int == create_records[i].dummy_int
+            assert result.dummy_str == create_records[i].dummy_str
+            assert result.dummy_float == create_records[i].dummy_float
+            assert result.dummy_bool == create_records[i].dummy_bool
+            assert result.dummy_array == create_records[i].dummy_array
+            assert result.dummy_json == create_records[i].dummy_json
+
+        for i in range(0, 100):
+            result = db_read_serial_model(session, DummySerialModel, i + 1)
+
+            assert result.sid == i + 1
+            assert result.dummy_int == create_records[i].dummy_int
+            assert result.dummy_str == create_records[i].dummy_str
+            assert result.dummy_float == create_records[i].dummy_float
+            assert result.dummy_bool == create_records[i].dummy_bool
+            assert result.dummy_array == create_records[i].dummy_array
+            assert result.dummy_json == create_records[i].dummy_json
+
+        for i in range(0, 100):
+            result = db_update_serial_model(session, DummySerialModel, update_records[i], i + 1)
+
+            assert result.sid == i + 1
+            assert result.dummy_int == update_records[i].dummy_int
+            assert result.dummy_str == update_records[i].dummy_str
+            assert result.dummy_float == update_records[i].dummy_float
+            assert result.dummy_bool == update_records[i].dummy_bool
+            assert result.dummy_array == update_records[i].dummy_array
+            assert result.dummy_json == update_records[i].dummy_json
+
+        results = db_read_serial_models(session, DummySerialModel, 0, 200)
+        assert len(results) == 100
+
+        for i, (result, update_record) in enumerate(zip(results, update_records)):
+            assert result.sid == i + 1
+            assert result.dummy_int == update_record.dummy_int
+            assert result.dummy_str == update_record.dummy_str
+            assert result.dummy_float == update_record.dummy_float
+            assert result.dummy_bool == update_record.dummy_bool
+            assert result.dummy_array == update_record.dummy_array
+            assert result.dummy_json == update_record.dummy_json
+
+        for i in range(0, 100):
+            result = db_read_serial_model(session, DummySerialModel, i + 1)
+
+            assert result.sid == i + 1
+            assert result.dummy_int == update_records[i].dummy_int
+            assert result.dummy_str == update_records[i].dummy_str
+            assert result.dummy_float == update_records[i].dummy_float
+            assert result.dummy_bool == update_records[i].dummy_bool
+            assert result.dummy_array == update_records[i].dummy_array
+            assert result.dummy_json == update_records[i].dummy_json
+
+        for i in range(0, 100):
+            result = db_delete_serial_model(session, DummySerialModel, i + 1)
+
+            assert result.sid == i + 1
+            assert result.dummy_int == update_records[i].dummy_int
+            assert result.dummy_str == update_records[i].dummy_str
+            assert result.dummy_float == update_records[i].dummy_float
+            assert result.dummy_bool == update_records[i].dummy_bool
+            assert result.dummy_array == update_records[i].dummy_array
+            assert result.dummy_json == update_records[i].dummy_json
+
+        results = db_read_serial_models(session, DummySerialModel, 0, 200)
+        assert len(results) == 0
+
+
 def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_test):
     scheme = make_scheme(Dialects.postgresql, Drivers.psycopg)
     host = fixture_postgresql_test.info.host
@@ -215,6 +328,7 @@ def test_db_record_model_crud(fixture_postgresql_test_proc, fixture_postgresql_t
         results = db_read_serial_models(session, DummyRecordModel, 0, 200)
         assert len(results) == 0
 
+
 def test_db_snapshot_model_crud(fixture_postgresql_test_proc, fixture_postgresql_test):
     scheme = make_scheme(Dialects.postgresql, Drivers.psycopg)
     host = fixture_postgresql_test.info.host
